@@ -1,42 +1,48 @@
-asFunction <- function(expr, envir=parent.frame(), ...) {
-  eval(substitute(function() x, list(x=expr)), envir=envir, ...)
+as_function <- function(expr, envir = parent.frame(), ...) {
+  eval(substitute(function() x, list(x = expr)), envir = envir, ...)
 }
 
 #' @importFrom utils installed.packages
-findBasePkgs <- local({
+find_base_pkgs <- local({
   pkgs <- NULL
   function() {
     if (length(pkgs) > 0L) return(pkgs)
     data <- installed.packages()
-    isBase <- (data[,"Priority"] %in% "base")
-    pkgs <<- rownames(data)[isBase]
+    is_base <- (data[, "Priority"] %in% "base")
+    pkgs <<- rownames(data)[is_base]
     pkgs
   }
 })
 
-isBasePkgs <- function(pkgs) {
+is_base_pkg <- function(pkgs) {
   pkgs <- gsub("^package:", "", pkgs)
-  pkgs %in% findBasePkgs()
+  pkgs %in% find_base_pkgs()
 }
 
 # cf. is.primitive()
 is.base <- function(x) {
   if (typeof(x) != "closure") return(FALSE)
-  isBasePkgs(environmentName(environment(x)))
+  is_base_pkg(environmentName(environment(x)))
 }
 
 # cf. is.primitive()
-is.internal <- function(x) {
+is_internal <- function(x) {
   if (typeof(x) != "closure") return(FALSE)
   body <- deparse(body(x))
-  any(grepl(".Internal", body, fixed=TRUE))
+  any(grepl(".Internal", body, fixed = TRUE))
 }
 
-hpaste <- function(..., sep="", collapse=", ", lastCollapse=NULL, maxHead=3L, maxTail=1L, abbreviate="...") {
-  if (is.null(lastCollapse)) lastCollapse <- collapse
+## From R.utils 2.0.2 (2015-05-23)
+hpaste <- function(..., sep="", collapse=", ", last_collapse=NULL,
+                   max_head=if (missing(last_collapse)) 3 else Inf,
+                   max_tail=if (is.finite(max_head)) 1 else Inf,
+                   abbreviate="...") {
+  max_head <- as.double(max_head)
+  max_tail <- as.double(max_tail)
+  if (is.null(last_collapse)) last_collapse <- collapse
 
   # Build vector 'x'
-  x <- paste(..., sep=sep)
+  x <- paste(..., sep = sep)
   n <- length(x)
 
   # Nothing todo?
@@ -44,24 +50,24 @@ hpaste <- function(..., sep="", collapse=", ", lastCollapse=NULL, maxHead=3L, ma
   if (is.null(collapse)) return(x)
 
   # Abbreviate?
-  if (n > maxHead + maxTail + 1) {
-    head <- x[seq_len(maxHead)]
-    tail <- rev(rev(x)[seq_len(maxTail)])
+  if (n > max_head + max_tail + 1) {
+    head <- x[seq_len(max_head)]
+    tail <- rev(rev(x)[seq_len(max_tail)])
     x <- c(head, abbreviate, tail)
     n <- length(x)
   }
 
   if (!is.null(collapse) && n > 1) {
-    if (lastCollapse == collapse) {
-      x <- paste(x, collapse=collapse)
+    if (last_collapse == collapse) {
+      x <- paste(x, collapse = collapse)
     } else {
-      xT <- paste(x[1:(n-1)], collapse=collapse)
-      x <- paste(xT, x[n], sep=lastCollapse)
+      x_head <- paste(x[1:(n - 1)], collapse = collapse)
+      x <- paste(x_head, x[n], sep = last_collapse)
     }
   }
 
   x
-} # hpaste()
+}
 
 
 ## From future 0.11.0
@@ -71,10 +77,12 @@ trim <- function(s) {
 
 
 ## From future 0.11.0
-hexpr <- function(expr, trim=TRUE, collapse="; ", maxHead=6L, maxTail=3L, ...) {
+hexpr <- function(expr, trim = TRUE, collapse = "; ", max_head = 6L,
+                  max_tail = 3L, ...) {
   code <- deparse(expr)
   if (trim) code <- trim(code)
-  hpaste(code, collapse=collapse, maxHead=maxHead, maxTail=maxTail, ...)
+  hpaste(code, collapse = collapse,
+         max_head = max_head, max_tail = max_tail, ...)
 } # hexpr()
 
 
